@@ -12,6 +12,7 @@ with 'Venus::Role::Catchable';
 with 'Venus::Role::Digestable';
 with 'Venus::Role::Doable';
 with 'Venus::Role::Dumpable';
+with 'Venus::Role::Matchable';
 with 'Venus::Role::Printable';
 with 'Venus::Role::Throwable';
 
@@ -91,6 +92,8 @@ L<Venus::Role::Doable>
 
 L<Venus::Role::Dumpable>
 
+L<Venus::Role::Matchable>
+
 L<Venus::Role::Printable>
 
 L<Venus::Role::Throwable>
